#!/usr/bin/env python
# -*- coding: UTF-8 -*-
##
##    Copyright (C) 2005 manatlan manatlan[at]gmail(dot)com
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published
## by the Free Software Foundation; version 2 only.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
import os

import gtk,gc

from __main__ import GladeApp
GladeApp.bindtextdomain("plugin","po")

class Winshow(GladeApp):
    glade=os.path.join(os.path.dirname(__file__), 'winshow.glade')

    def init(self):
        self.ln = Winshow.ln    # bad system to pass parameters to the class, see __init__.py
        self.idx=Winshow.idx
        self.selected=[]        # to be able to handle a new selection (reselect with space)

        self.size = gtk.gdk.screen_height()

        self.image.set_flags(gtk.CAN_FOCUS)
        self.image.grab_focus()

        #~ self.main_widget.fullscreen()
        self.main_widget.resize(gtk.gdk.screen_width(), gtk.gdk.screen_height())
        self.show()


    def show(self):
        if self.idx >= len(self.ln):
            self.idx = len(self.ln)-1
        if self.idx < 0:
            self.idx = 0

        node = self.ln[self.idx]
        info = node.getInfo()


        if len(self.selected)>0:
            nbSelected = _("(%d selected)") % len(self.selected)
        else:
            nbSelected= ""

        #~ self.label.angle=30
        #~ color = gtk.gdk.color_parse("green")
        #~ self.label.modify_bg(gtk.STATE_NORMAL, color)

        pos=self.idx+1
        max=len(self.ln)
        name=node.name
        readonly=info["readonly"] and "READ ONLY" or ""
        folder=" /".join( node.folder.split("/"))
        resolution=info["resolution"]
        tags=", ".join(info["tags"])
        comment=info["comment"]
        exifdate=cd2rd(info["exifdate"])
        filedate=cd2rd(info["filedate"])
        filesize=format_file_size_for_display(info["filesize"])

        msg = _("""
%(pos)d/%(max)d %(nbSelected)s
%(name)s

%(readonly)s

<u>FOLDER :</u>
<small>%(folder)s</small>

<u>RESOLUTION:</u>
%(resolution)s

<u>TAGS :</u>
%(tags)s

<u>COMMENT :</u>
%(comment)s

<u>EXIF DATE :</u>
%(exifdate)s

<u>FILE DATE :</u>
%(filedate)s

<u>FILE SIZE :</u>
%(filesize)s
""") % locals()

        pb = node.getImage()
        (wx,wy) = pb.get_width(),pb.get_height()
        rx=1.0*wx/self.size
        ry=1.0*wy/self.size
        if rx>ry:
            rr=rx
        else:
            rr=ry
        pb = pb.scale_simple(int(wx/rr),int(wy/rr),gtk.gdk.INTERP_NEAREST)

        self.image.set_from_pixbuf(pb)

        #~ self.label.set_text( msg )
        if node in self.selected:
            msg = "<b>"+msg+"</b>"
        self.label.set_markup(msg);

        gc.collect()

    def on_WinShow_delete_event(self, widget, *args):
        self.quit()

    def on_WinShow_key_press_event(self, widget, b):
        if (b.keyval == 65365) or (b.keyval == 65362) or (b.keyval == 65361):
            self.idx-=1
            self.show()
        elif b.keyval == 65366 or (b.keyval == 65363) or (b.keyval ==65364):
            self.idx+=1
            self.show()
        elif b.keyval == 65360: # HOME
            self.idx=0
            self.show()
        elif b.keyval == 65367: # END
            self.idx=len(self.ln) -1
            self.show()
        elif b.keyval == 65307: #ESC
            self.on_WinShow_button_press_event(1,1)
        elif b.keyval == 32: #SPACE
            # add/remove this photo to a new selection
            node=self.ln[self.idx]
            if node in self.selected:
                self.selected.remove(node)
            else:
                self.selected.append(node)
            self.show()

    def on_WinShow_button_press_event(self, widget, *args):
        self.quit()

    def on_eventbox1_scroll_event(self, widget, b):
        if int(b.direction)==1:
            self.idx+=1
        else:
            self.idx-=1

        self.show()





# some function needed by winshow :
#----------------------------------------------------------------------

def cd2rd(f): #yyyymmddhhiiss -> dd/mm/yyyy hh:ii:ss
   if f:
      if len(f) == 14:
         return f[6:8]+"/"+f[4:6]+"/"+f[:4]+" "+f[8:10]+":"+f[10:12]+":"+f[12:14]
      else:
         return f[6:8]+"/"+f[4:6]+"/"+f[:4]
   else:
      return f


def format_file_size_for_display(file_size):
    KILOBYTE_FACTOR = 1024.0
    MEGABYTE_FACTOR = 1024.0 ** 2
    GIGABYTE_FACTOR = 1024.0 ** 3

    if file_size < KILOBYTE_FACTOR:
        return _('%u bytes') % file_size
    if file_size < MEGABYTE_FACTOR:
        return _('%.1f KB') % (file_size/KILOBYTE_FACTOR)
    if file_size < GIGABYTE_FACTOR:
        return _('%.1f MB') % (file_size/MEGABYTE_FACTOR)
    return _('%.1f GB') % (file_size/GIGABYTE_FACTOR)


def main():
    win_show = Winshow()

    win_show.loop()

if __name__ == "__main__":
    main()

